==> haskell-http-date-0.0.11-141-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-date
version:              0.0.11
visibility:           public
id:                   http-date-0.0.11-KhtaDHtbt67LHeDFyPImyW
key:                  http-date-0.0.11-KhtaDHtbt67LHeDFyPImyW
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             HTTP Date parser/formatter
description:          Fast parser and formatter for HTTP Date
category:             Network, Web
abi:                  6f11dcc2abf290d45d310a84a11e3dc8
exposed:              True
exposed-modules:      Network.HTTP.Date
hidden-modules:
    Network.HTTP.Date.Converter Network.HTTP.Date.Formatter
    Network.HTTP.Date.Types Network.HTTP.Date.Parser

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-date-0.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-date-0.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-date
hs-libraries:         HShttp-date-0.0.11-KhtaDHtbt67LHeDFyPImyW
depends:
    array-0.5.4.0 attoparsec-0.14.4-IUoeEKVn7Gr6GqDDI9lyTI
    base-4.16.4.0 bytestring-0.11.4.0 time-1.11.1.1

haddock-interfaces:   /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html:         /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-date-0.0.11-142-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-date
version:              0.0.11
visibility:           public
id:                   http-date-0.0.11-I8BcKjIrfQeGmsEBBVVKYl
key:                  http-date-0.0.11-I8BcKjIrfQeGmsEBBVVKYl
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             HTTP Date parser/formatter
description:          Fast parser and formatter for HTTP Date
category:             Network, Web
abi:                  ab1d446399842b7fbc6e0c44a601a34d
exposed:              True
exposed-modules:      Network.HTTP.Date
hidden-modules:
    Network.HTTP.Date.Converter Network.HTTP.Date.Formatter
    Network.HTTP.Date.Types Network.HTTP.Date.Parser

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-date-0.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-date-0.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-date
hs-libraries:         HShttp-date-0.0.11-I8BcKjIrfQeGmsEBBVVKYl
depends:
    array-0.5.4.0 attoparsec-0.14.4-DN7s9Fr9c113K5agmmE0LB
    base-4.16.4.0 bytestring-0.11.4.0 time-1.11.1.1

haddock-interfaces:   /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html:         /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
